# Generated by Django 4.2.3 on 2023-07-31 06:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ReadHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(choices=[('altnight', 'あるとな'), ('furi', 'ふり')], max_length=255, verbose_name='名前')),
                ('category', models.CharField(choices=[('tech', '技術書'), ('business', 'ビジネス書')], max_length=255, verbose_name='カテゴリ')),
                ('title', models.CharField(max_length=255, verbose_name='書籍名')),
                ('price', models.IntegerField(verbose_name='価格')),
                ('read_at', models.DateField(verbose_name='読了日')),
                ('is_public', models.BooleanField(verbose_name='公開するかどうか')),
                ('is_favorite', models.BooleanField(blank=True, null=True, verbose_name='評価')),
            ],
            options={
                'db_table': 'read_history',
            },
        ),
    ]
